pub enum KeyEventKind {
Press,
Repeat,
Release,
}Expand description
Represents a keyboard event kind.
Variants
Implementations
Sourceimpl KeyEventKind
impl KeyEventKind
Sourcepub const fn is_press(&self) -> bool
pub const fn is_press(&self) -> bool
Returns true if this value is of type Press. Returns false otherwise
Sourcepub const fn is_repeat(&self) -> bool
pub const fn is_repeat(&self) -> bool
Returns true if this value is of type Repeat. Returns false otherwise
Sourcepub const fn is_release(&self) -> bool
pub const fn is_release(&self) -> bool
Returns true if this value is of type Release. Returns false otherwise