pub enum Intent {
Show 48 variants
Quit,
NextTab,
PreviousTab,
SelectTab(Tab),
OpenCommandLine,
CloseTopmost,
SubmitCommandLine,
ConfirmYes,
InsertChar(char),
DeleteBackward,
MoveLeft,
MoveRight,
MoveHome,
MoveEnd,
KillToEnd,
KillWordBackward,
Vim(VimAction),
ToggleEditMode,
OpenHelp,
ConsoleFocus,
ConsoleBlur,
ConsoleSubmit,
ConsoleInterrupt,
ConsoleHistoryPrev,
ConsoleHistoryNext,
ConsoleCyclePane,
ScrollLineUp,
ScrollLineDown,
ScrollPageUp,
ScrollPageDown,
ListSelectNext,
ListSelectPrev,
ListDelete,
ListEdit,
RefreshTab,
EditConfig,
SelectNext,
SelectPrev,
SelectConfirm,
ColNext,
ColPrev,
RowNext,
RowPrev,
SplitAddRow,
SplitRemoveRow,
CompleteCommandLine,
DateStepBack,
DateStepForward,
}Variants
Quit
NextTab
PreviousTab
SelectTab(Tab)
OpenCommandLine
CloseTopmost
SubmitCommandLine
ConfirmYes
Confirm the topmost confirm overlay (equivalent to pressing y).
InsertChar(char)
DeleteBackward
MoveLeft
MoveRight
MoveHome
MoveEnd
KillToEnd
KillWordBackward
Vim(VimAction)
ToggleEditMode
OpenHelp
ConsoleFocus
ConsoleBlur
ConsoleSubmit
ConsoleInterrupt
ConsoleHistoryPrev
ConsoleHistoryNext
ConsoleCyclePane
ScrollLineUp
ScrollLineDown
ScrollPageUp
ScrollPageDown
ListSelectNext
ListSelectPrev
ListDelete
Delete the currently selected list item (pushes a confirm overlay).
ListEdit
Open the tag editor for the currently selected list item.
RefreshTab
EditConfig
SelectNext
SelectPrev
SelectConfirm
ColNext
Splits: move focus to next column within the focused row.
ColPrev
Splits: move focus to previous column within the focused row.
RowNext
Splits: move focus to next row.
RowPrev
Splits: move focus to previous row.
SplitAddRow
Splits: append a new blank row.
SplitRemoveRow
Splits: remove the focused row (minimum 1 kept).
CompleteCommandLine
Complete the current command-palette token (Tab in the command line).
DateStepBack
Step the focused Date field forward by one day (Up key).
DateStepForward
Step the focused Date field forward by one day (Down key).