longest_common_prefix

Function longest_common_prefix 

pub fn longest_common_prefix(candidates: &[String]) -> String
Return the longest string that is a common prefix of all candidates. Returns an empty string when candidates is empty or contains no common prefix.