pub struct Insets {
pub left: u16,
pub right: u16,
pub top: u16,
pub bottom: u16,
}Expand description
Edge insets used to shrink a ViewContext to a smaller size.
Used by parents that want to render a child inside a padded box: subtract the insets from the parent size to get the child’s allocated size.
Fields
left: u16right: u16top: u16bottom: u16Implementations