pub struct ListTab {
pub request_form: String,
pub state: Fetch<Vec<ListRow>>,
pub selected: usize,
pub scroll: usize,
/* private fields */
}Fields
request_form: Stringstate: Fetch<Vec<ListRow>>selected: usizescroll: usizeImplementations
Sourceimpl ListTab
impl ListTab
pub fn new( request_form: impl Into<String>, schema: &'static EntitySchema, ) -> Self
Sourcepub fn set_loading_id(&mut self, id: i64)
pub fn set_loading_id(&mut self, id: i64)
Update loading id after the eval assigned a real envelope id.
Sourcepub fn on_reply(&mut self, wire: &str)
pub fn on_reply(&mut self, wire: &str)
Process a routed reply wire frame and update fetch state.
Sourcepub fn selected_id(&self) -> Option<&str>
pub fn selected_id(&self) -> Option<&str>
Return the entity id of the focused row, or None when not loaded or no id.
pub fn select_next(&mut self)
pub fn select_prev(&mut self)