assert_buffer_eq

Function assert_buffer_eq 

pub fn assert_buffer_eq<S: AsRef<str>>(terminal: &TestTerminal, expected: &[S])
Asserts a test terminal buffer matches the expected output. Each element of the expected vector represents a row. Trailing whitespace is ignored on each line.