pub struct AmountWidget { /* private fields */ }Expand description
A text field accepting only amount characters (digits, -, ., /).
Implementations
Sourceimpl AmountWidget
impl AmountWidget
pub fn new(mode: EditMode) -> Self
pub fn with_value(mode: EditMode, value: impl Into<String>) -> Self
Sourcepub fn insert_char(&mut self, c: char)
pub fn insert_char(&mut self, c: char)
Insert c only if it is a valid amount character.
Sourcepub fn as_editor_mut(&mut self) -> &mut Editor
pub fn as_editor_mut(&mut self) -> &mut Editor
Direct access to the inner editor for motion and delete operations.