pub struct Line { /* private fields */ }Expand description
A single line of styled terminal output, composed of Spans.
ANSI escape codes are emitted only when to_ansi_string
is called, keeping the data model free of formatting concerns.
Implementations
Sourceimpl Line
impl Line
pub fn new(s: impl Into<String>) -> Self
pub fn styled(text: impl Into<String>, color: Color) -> Self
pub fn with_style(text: impl Into<String>, style: Style) -> Self
pub fn spans(&self) -> &[Span]
pub fn is_empty(&self) -> bool
pub fn prepend(self, text: impl Into<String>) -> Self
pub fn push_text(&mut self, text: impl Into<String>)
pub fn push_styled(&mut self, text: impl Into<String>, color: Color)
pub fn push_with_style(&mut self, text: impl Into<String>, style: Style)
pub fn push_span(&mut self, span: Span)
pub fn append_line(&mut self, other: &Line)
pub fn extend_bg_to_width(&mut self, target_width: usize)
pub fn to_ansi_string(&self) -> String
Sourcepub fn display_width(&self) -> usize
pub fn display_width(&self) -> usize
Display width in terminal columns (accounts for unicode widths).
Sourcepub fn soft_wrap(&self, width: u16) -> Vec<Line>
pub fn soft_wrap(&self, width: u16) -> Vec<Line>
Soft-wrap this line to fit within width columns.
pub fn plain_text(&self) -> String