pub fn assert_buffer_eq<S: AsRef<str>>(terminal: &TestTerminal, expected: &[S])Expand description
Asserts a test terminal buffer matches the expected output. Each element of the expected vector represents a row. Trailing whitespace is ignored on each line.